@@ -16,6 +16,9 @@
 //!     .saturate(0.3);
 //!
 //! assert_eq!(new_color.to_u32(), 0x201111ff);
+//!
+//! // 4 bytes
+//! assert_eq!(4, std::mem::size_of::<RGBA>());
 //! ```
 //!
 //! # Storage Formats
@@ -67,6 +70,9 @@ use std::marker::PhantomData;
 /// ```
 /// type RGBA = inku::Color<inku::RGBA>;
 /// assert_eq!(RGBA::new(0xfacadeff).to_u32(), 0xfacadeff);
+///
+/// // 4 bytes
+/// assert_eq!(4, std::mem::size_of::<RGBA>());
 /// ```
 #[derive(Copy, Clone, PartialEq, Default, Hash)]
 pub struct Color<T: Storage>(u32, PhantomData<T>);
@@ -216,7 +222,7 @@ impl<T: Storage> Color<T> {
         // First convert to HSL
         let (h, s, mut l, a) = self.to_hsla();
 
-        // Decrease the lightness and ensure we don't go under 0.0
+        // Decrease the lightness and ensure we don't go below 0.0
         l = (l - percent * 100.0).max(0.0);
 
         Color::from_hsla(h, s, l, a)
@@ -254,7 +260,7 @@ impl<T: Storage> Color<T> {
         // First convert to HSL
         let (h, mut s, l, a) = self.to_hsla();
 
-        // Decrease the saturation and ensure we don't go under 0.0
+        // Decrease the saturation and ensure we don't go below 0.0
         s = (s - percent * 100.0).max(0.0);
 
         Color::from_hsla(h, s, l, a)
@@ -300,6 +306,23 @@ impl<T: Storage> Color<T> {
         self.brightness() > 0.5
     }
 
+    /// Modify the individual channels.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let color = inku::Color::<inku::RGBA>::new(0x00000011);
+    /// assert_eq!(
+    ///     color.map(|r, g, b, a| (r, g, b, a + 0x22)).to_u32(),
+    ///     0x00000033
+    /// );
+    /// ```
+    pub fn map(&self, f: fn(u8, u8, u8, u8) -> (u8, u8, u8, u8)) -> Self {
+        let (r, g, b, a) = self.to_rgba();
+        let (r, g, b, a) = f(r, g, b, a);
+        Self::from_rgba(r, g, b, a)
+    }
+
     fn to_rgba(self) -> (u8, u8, u8, u8) {
         let (r, g, b, a) = T::decode(self.0);
         (r, g, b, a)
@@ -309,6 +332,10 @@ impl<T: Storage> Color<T> {
         Self::new(T::encode(r, g, b, a))
     }
 
+    // NOTE: These {to,from}_hsla functions are private because if you're already dealing with
+    // colors in HSLA you're probably better off keeping your colors in HSLA so you don't lose
+    // fidelity.
+
     fn to_hsla(self) -> (f64, f64, f64, u8) {
         let (r, g, b, a) = self.to_rgba();
         let (h, s, l) = rgb_to_hsl(r, g, b);
@@ -324,7 +351,12 @@ impl<T: Storage> Color<T> {
 #[cfg(not(test))]
 impl<T: Storage> fmt::Debug for Color<T> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "Color<{}>(", std::any::type_name::<T>())?;
+        let storage = format!("{}", std::any::type_name::<T>())
+            .split("::")
+            .last()
+            .expect("no type name")
+            .to_owned();
+        write!(f, "Color<{}>(", storage)?;
         T::write_hex(f, self.0)?;
         write!(f, ")")
     }
@@ -485,21 +517,21 @@ mod tests {
         fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
             use crossterm::style;
 
-            let fg = if self.is_light() {
+            let fg = style::SetForegroundColor(if self.is_light() {
                 style::Color::Black
             } else {
                 style::Color::White
-            };
+            });
             let (r, g, b, _a) = self.to_rgba();
-            let bg = style::Color::Rgb { r, g, b };
+            let bg = style::SetBackgroundColor(style::Color::Rgb { r, g, b });
 
-            write!(
-                f,
-                "Color<{}>({}{}",
-                std::any::type_name::<T>(),
-                style::SetForegroundColor(fg),
-                style::SetBackgroundColor(bg),
-            )?;
+            let storage = format!("{}", std::any::type_name::<T>())
+                .split("::")
+                .last()
+                .expect("no type name")
+                .to_owned();
+
+            write!(f, "Color<{}>({}{}", storage, fg, bg)?;
             T::write_hex(f, self.0)?;
             write!(f, "{})", style::ResetColor)
         }
@@ -630,6 +662,25 @@ mod tests {
         assert!(!dark.is_light());
     }
 
+    #[test]
+    fn map() {
+        let color = Color::<ZRGB>::new(0x00000000);
+        assert_eq!(
+            color
+                .map(|r, g, b, a| (r + 1, g + 2, b + 3, a + 4))
+                .to_u32(),
+            0x00010203
+        );
+
+        let color = Color::<RGBA>::new(0x00000000);
+        assert_eq!(
+            color
+                .map(|r, g, b, a| (r + 1, g + 2, b + 3, a + 4))
+                .to_u32(),
+            0x01020304
+        );
+    }
+
     #[test]
     fn storage() {
         assert_eq!(0x00bbccdd, ZRGB::init(0xaabbccdd));
